@@ -34,32 +34,35 @@ OC.L10N.register(
     "Delete" : "حذف",
     "Add new" : "افزودن مورد تازه",
     "Untitled calendar" : "تقویم بدون عنوان",
-    "Edit name" : "ویرایش نام",
-    "Saving name …" : "ذخیره نام",
-    "Edit color" : "ویرایش رنگ",
-    "Saving color …" : "ذخیره رنگ",
-    "Copy private link" : "کپی کردن پیوند خصوصی",
-    "Export" : "دریافت خروجی",
-    "Unshare from me" : "بی خبر از من",
+    "Shared with you by" : "با شما به اشتراک گذاشته شده است",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
-    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
-    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
-    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
-    "An error occurred, unable to rename the calendar." : "خطایی روی داد ، قادر به تغییر نام تقویم نیست.",
-    "An error occurred, unable to change the calendar's color." : "خطایی روی داد ، قادر به تغییر رنگ تقویم نیست.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف تقویم در {شمارش معکوس} ثانیه ها","حذف تقویم در {شمارش معکوس} ثانیه ها"],
-    "Share link" : "لینک را به اشتراک بگذارید",
-    "Publish calendar" : "تقویم را منتشر کنید",
-    "Publishing calendar" : "در حال انتشار تقویم ",
-    "Copy public link" : "پیوند عمومی را کپی کنید",
-    "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
-    "Enter one address" : "یک آدرس وارد کنید",
-    "Sending email …" : "ارسال ایمیل…",
+    "New calendar" : "تقویم جدید",
+    "Creating calendar …" : "ایجاد تقویم ...",
+    "New calendar with task list" : "تقویم جدید با لیست کارها",
+    "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
+    "Creating subscription …" : "ایجاد اشتراک…",
+    "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
     "Copy subscription link" : "پیوند اشتراک را کپی کنید",
     "Copying link …" : "کپی پیوند ...",
     "Copied link" : "پیوند کپی شد",
     "Could not copy link" : "نمی توان پیوند را کپی کرد",
+    "Export" : "دریافت خروجی",
+    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
+    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
+    "Trash bin" : "زباله‌دان",
+    "Name" : "نام",
+    "Deleted" : "حذف شده",
+    "Restore" : "بازیابی",
+    "Delete permanently" : "حذف قطعی",
+    "Empty trash bin" : "خالی کردن سطل زباله",
+    "Share link" : "لینک را به اشتراک بگذارید",
+    "Copy public link" : "پیوند عمومی را کپی کنید",
+    "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
+    "Enter one address" : "یک آدرس وارد کنید",
+    "Sending email …" : "ارسال ایمیل…",
     "Copy embedding code" : "کد تعبیه شده را کپی کنید",
     "Copying code …" : "کپی کردن کد ...",
     "Copied code" : "کد کپی شد",
@@ -71,25 +74,14 @@ OC.L10N.register(
     "Embed code copied to clipboard." : "کد قرار داده شده در حافظه کپی شد.",
     "Embed code could not be copied to clipboard." : "کد جاسازی را نمی توان در کلیپ بورد کپی کرد.",
     "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
-    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
-    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
     "can edit" : "می توان ویرایش کرد",
     "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "خطایی روی داد ، قادر به تغییر تقویم عدم اشتراک گذاری نیست.",
     "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
-    "New calendar" : "تقویم جدید",
-    "Creating calendar …" : "ایجاد تقویم ...",
-    "New calendar with task list" : "تقویم جدید با لیست کارها",
-    "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
-    "Creating subscription …" : "ایجاد اشتراک…",
-    "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
-    "Trash bin" : "زباله‌دان",
-    "Name" : "نام",
-    "Deleted" : "حذف شده",
-    "Restore" : "بازیابی",
-    "Delete permanently" : "حذف قطعی",
-    "Empty trash bin" : "خالی کردن سطل زباله",
+    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
+    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
+    "Copy private link" : "کپی کردن پیوند خصوصی",
+    "Unshare from me" : "بی خبر از من",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام فایل",
@@ -296,6 +288,7 @@ OC.L10N.register(
     "Custom color" : "رنگ سفارشی",
     "Special color of this event. Overrides the calendar-color." : "رنگ ویژه این رویداد. رنگ تقویم را نادیده می گیرد.",
     "Chat room for event" : "اتاق گپ برای رویداد",
+    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
     "Imported {filename}" : "وارد شده {نام پرونده}",
     "Meditation" : "مراقبه",
     "Relaxing" : "آرامش بخش",
