@@ -8,11 +8,13 @@ OC.L10N.register(
     "List" : "List",
     "Edit" : "தொகுக்க",
     "Delete" : "நீக்குக",
+    "New calendar" : "புதிய நாட்காட்டி",
     "Export" : "ஏற்றுமதி",
+    "Name" : "பெயர்",
+    "Restore" : "மீட்டெடு",
+    "Delete permanently" : "நிரந்தரமாக நீக்கவும்",
     "Share link" : "Share link",
     "can edit" : "தொகுக்க முடியும்",
-    "New calendar" : "புதிய நாட்காட்டி",
-    "Name" : "பெயர்",
     "Cancel" : "இரத்து செய்க",
     "Actions" : "செயல்கள்",
     "Location" : "இடம்",
